/*
 * Copyright (C) 2022 KylinSoft Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program. If not, see <https://www.gnu.org/licenses/>.
 */

#ifndef CONFIG_H
#define CONFIG_H

#include <QObject>

class QSettings;

class Config : public QObject
{
    Q_OBJECT
public:
    explicit Config(QObject *parent = nullptr);

    enum DesktopMode {
        Tablet,
        EduScreen,
    };
    Q_ENUM(DesktopMode);

    struct ContainerInfo
    {
        QString containerName;
        QStringList desktopFiles;
        QList<int> placeholder;
        bool titleEditable;
        bool containerEditable;
        QString containerCategory;
    };

    DesktopMode desktopMode() const;

    QStringList appWidgetList() const;

    ///
    /// \brief desktopLayout
    /// \code
    ///     int row, column;
    ///     auto [row, column] = desktopLayout();
    /// \endcode
    /// \return
    ///
    std::tuple<int, int> desktopLayout() const;

    QMap<QString, QStringList> defaultGroups() const;
    QList<ContainerInfo> defaultContainers() const;
    QList<int> layoutList(QString layout) const;

private:
    QSettings *m_confSettings;
    const QString kConfFile = "/etc/ukui-tablet-desktop.conf";
};

#endif // CONFIG_H
