/*
 * Copyright (C) 2022 KylinSoft Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program. If not, see <https://www.gnu.org/licenses/>.
 */

#ifndef TASKBARAPPMANAGER_H
#define TASKBARAPPMANAGER_H

#include <QObject>
#include <QList>
#include <QFileSystemWatcher>
#include <QDebug>

class Settings;
class TaskbarAppManager : public QObject
{
    Q_OBJECT
public:
    enum TaskbarAction {
        Delete,
        Add,
        Move
    };
    Q_ENUM(TaskbarAction)

    explicit TaskbarAppManager(QObject *parent = nullptr);
    QStringList appDesktopfiles() const;
    void checkAppDesktopfiles(const QStringList &preDesktopfiles);
    void updatePanelConf(const QList<QString> &taskbarData);

signals:
    void taskbarAppChanged(const QStringList taskbarDesktopName, TaskbarAppManager::TaskbarAction action);

public slots:
    void taskBarDataChanged();

private:
    void loadSettingsFile();
    QStringList readTaskbarPanelConf();

private:
    QStringList m_appsDesktopFiles;
    QFileSystemWatcher *m_fileWatcher; //监听panel.conf变化
    QString m_settingsFile;    
};

#endif // TASKBARAPPMANAGER_H
