/*
 * Copyright (C) 2022 KylinSoft Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program. If not, see <https://www.gnu.org/licenses/>.
 */

#include "configmanager.h"
#include <QSettings>
#include <QStandardPaths>
#include <QDebug>

ConfigManager::ConfigManager(QObject *parent)
    : QObject{parent}
{
    QStringList configPaths = QStandardPaths::standardLocations(QStandardPaths::ConfigLocation);
    QString configFile = configPaths.isEmpty() ?
                "/tmp/ukui-tablet-desktop.conf" :
                configPaths.first() + "/ukui-tablet-desktop.conf";
    m_settings = new QSettings(configFile, QSettings::IniFormat);
}

int ConfigManager::untitledGroupCount() const
{
    return m_settings->value("UntitledGroupCount").toInt();
}

void ConfigManager::setUntitledGroupCount(int count)
{
    m_settings->setValue("UntitledGroupCount", count);
}

QStringList ConfigManager::uninstallAppWhiteList()
{
    const QString configFile =
            "/etc/ukui-tablet-desktop/tablet/uninstallAppWhiteList.conf";
    QSettings settings(configFile, QSettings::IniFormat);
    return settings.value("UninstallAppWhiteList/apps").toStringList();
}
